# -*- coding: utf-8 -*-
"""AMPidentifier — A Python toolkit for Antimicrobial Peptide prediction."""

__version__ = "1.0.0"
__author__ = "Madson A. de Luna Aragão"
__email__ = "madsondeluna@gmail.com"